[gtk+/wip/matthiasc/icon-size: 12/15] enums: Change GtkIconSize values



commit 8560d314adcd31b45be08fce977a9804aad3cc6e
Author: Matthias Clasen <mclasen redhat com>
Date:   Tue Nov 14 21:14:47 2017 -0500

    enums: Change GtkIconSize values
    
    The new values are the ones we intend to keep. The old ones had
    duplicated meanings and nobody knew which one to take.

 demos/gtk-demo/clipboard.c                     |    4 +--
 demos/gtk-demo/dialog.c                        |    1 +
 demos/gtk-demo/font-features.ui                |   43 ------------------------
 demos/gtk-demo/gtkfishbowl.c                   |    5 ++-
 demos/gtk-demo/images.c                        |    2 +
 demos/gtk-demo/listbox.c                       |    5 ++-
 demos/gtk-demo/revealer.ui                     |   18 +++++-----
 demos/gtk-demo/toolpalette.c                   |    2 +-
 demos/icon-browser/window.ui                   |    1 -
 demos/widget-factory/widget-factory.ui         |    2 -
 docs/tools/widgets.c                           |    6 ++--
 examples/application10/window.ui               |    1 -
 examples/application7/window.ui                |    1 -
 examples/application8/window.ui                |    1 -
 examples/application9/window.ui                |    1 -
 gtk/gtkcellrendererpixbuf.c                    |    4 +-
 gtk/gtkcellrendererspinner.c                   |    4 +-
 gtk/gtkenums.h                                 |   27 ++++++---------
 gtk/gtkiconhelper.c                            |    5 ++-
 gtk/gtkicontheme.c                             |   36 ++-----------------
 gtk/gtkimage.c                                 |    4 +-
 gtk/gtkmountoperation.c                        |    1 +
 gtk/gtkprintbackend.c                          |    1 +
 gtk/gtkprintunixdialog.c                       |    2 +-
 gtk/gtkrecentchooserdefault.c                  |   12 ++-----
 gtk/gtkstackswitcher.c                         |    4 +-
 gtk/gtktoolbutton.c                            |    9 +----
 gtk/inspector/general.ui                       |    2 -
 gtk/inspector/misc-info.ui                     |    5 ---
 gtk/ui/gtkpagesetupunixdialog.ui               |    4 --
 gtk/ui/gtkpathbar.ui                           |    2 -
 gtk/ui/gtkplacesviewrow.ui                     |    1 -
 gtk/ui/gtkprintunixdialog.ui                   |    1 -
 gtk/ui/gtksearchbar.ui                         |    1 -
 tests/dialog.ui                                |    1 -
 tests/selectionmode.ui                         |    3 --
 tests/testdnd2.c                               |    6 ++--
 tests/testflowbox.c                            |    1 +
 tests/testgiconpixbuf.c                        |    2 +
 tests/testimage.c                              |    4 ++
 tests/testnotebookdnd.c                        |   20 ++---------
 tests/testtoolbar.c                            |    1 +
 tests/testverticalcells.c                      |    2 +-
 tests/visuals/osd-toolbars.ui                  |    8 ----
 testsuite/reftests/gtk-icontheme-sizing.ref.ui |    1 -
 testsuite/reftests/icon-vfuncs.ui              |    1 -
 testsuite/reftests/iconview-empty.ref.ui       |    3 --
 47 files changed, 73 insertions(+), 198 deletions(-)
---
diff --git a/demos/gtk-demo/clipboard.c b/demos/gtk-demo/clipboard.c
index 77230e7..53d203f 100644
--- a/demos/gtk-demo/clipboard.c
+++ b/demos/gtk-demo/clipboard.c
@@ -70,7 +70,6 @@ get_image_surface (GtkImage *image)
   const gchar *icon_name;
   GtkIconTheme *icon_theme;
   int width;
-  GtkIconSize size;
 
   switch (gtk_image_get_storage_type (image))
     {
@@ -78,9 +77,8 @@ get_image_surface (GtkImage *image)
       return cairo_surface_reference (gtk_image_get_surface (image));
     case GTK_IMAGE_ICON_NAME:
       icon_name = gtk_image_get_icon_name (image);
-      size = gtk_image_get_icon_size (image);
       icon_theme = gtk_icon_theme_get_for_display (gtk_widget_get_display (GTK_WIDGET (image)));
-      gtk_icon_size_lookup (size, &width, NULL);
+      gtk_icon_size_lookup (GTK_ICON_SIZE_INHERIT, &width, NULL);
       return gtk_icon_theme_load_surface (icon_theme, icon_name, width, 1, NULL, 
GTK_ICON_LOOKUP_GENERIC_FALLBACK, NULL);
     default:
       g_warning ("Image storage type %d not handled",
diff --git a/demos/gtk-demo/dialog.c b/demos/gtk-demo/dialog.c
index fd130d7..0f2e00a 100644
--- a/demos/gtk-demo/dialog.c
+++ b/demos/gtk-demo/dialog.c
@@ -59,6 +59,7 @@ interactive_dialog_clicked (GtkButton *button,
   gtk_box_pack_start (GTK_BOX (content_area), hbox);
 
   image = gtk_image_new_from_icon_name ("dialog-question");
+  gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_LARGE);
   gtk_box_pack_start (GTK_BOX (hbox), image);
 
   table = gtk_grid_new ();
diff --git a/demos/gtk-demo/font-features.ui b/demos/gtk-demo/font-features.ui
index 0bd2645..b3da993 100644
--- a/demos/gtk-demo/font-features.ui
+++ b/demos/gtk-demo/font-features.ui
@@ -84,7 +84,6 @@
                                   <object class="GtkImage" id="kern_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -137,7 +136,6 @@
                                   <object class="GtkImage" id="liga_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -169,7 +167,6 @@
                                   <object class="GtkImage" id="dlig_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -201,7 +198,6 @@
                                   <object class="GtkImage" id="hlig_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -233,7 +229,6 @@
                                   <object class="GtkImage" id="clig_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -286,7 +281,6 @@
                                   <object class="GtkImage" id="smcp_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -318,7 +312,6 @@
                                   <object class="GtkImage" id="c2sc_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -350,7 +343,6 @@
                                   <object class="GtkImage" id="pcap_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -382,7 +374,6 @@
                                   <object class="GtkImage" id="c2pc_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -414,7 +405,6 @@
                                   <object class="GtkImage" id="unic_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -446,7 +436,6 @@
                                   <object class="GtkImage" id="cpsp_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -478,7 +467,6 @@
                                   <object class="GtkImage" id="case_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -532,7 +520,6 @@
                                     <property name="visible">1</property>
                                     <property name="opacity">0</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -555,7 +542,6 @@
                                   <object class="GtkImage" id="lnum_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -579,7 +565,6 @@
                                   <object class="GtkImage" id="onum_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -625,7 +610,6 @@
                                     <property name="visible">1</property>
                                     <property name="opacity">0</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -648,7 +632,6 @@
                                   <object class="GtkImage" id="pnum_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -672,7 +655,6 @@
                                   <object class="GtkImage" id="tnum_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -718,7 +700,6 @@
                                     <property name="visible">1</property>
                                     <property name="opacity">0</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -741,7 +722,6 @@
                                   <object class="GtkImage" id="frac_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -765,7 +745,6 @@
                                   <object class="GtkImage" id="afrc_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -810,7 +789,6 @@
                                   <object class="GtkImage" id="zero_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -842,7 +820,6 @@
                                   <object class="GtkImage" id="nalt_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -874,7 +851,6 @@
                                   <object class="GtkImage" id="sinf_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -927,7 +903,6 @@
                                   <object class="GtkImage" id="swsh_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -959,7 +934,6 @@
                                   <object class="GtkImage" id="cswh_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -991,7 +965,6 @@
                                   <object class="GtkImage" id="locl_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -1023,7 +996,6 @@
                                   <object class="GtkImage" id="calt_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -1055,7 +1027,6 @@
                                   <object class="GtkImage" id="hist_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -1087,7 +1058,6 @@
                                   <object class="GtkImage" id="salt_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -1119,7 +1089,6 @@
                                   <object class="GtkImage" id="titl_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -1151,7 +1120,6 @@
                                   <object class="GtkImage" id="rand_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -1183,7 +1151,6 @@
                                   <object class="GtkImage" id="subs_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -1215,7 +1182,6 @@
                                   <object class="GtkImage" id="sups_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -1268,7 +1234,6 @@
                                   <object class="GtkImage" id="init_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -1300,7 +1265,6 @@
                                   <object class="GtkImage" id="medi_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -1332,7 +1296,6 @@
                                   <object class="GtkImage" id="fina_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -1364,7 +1327,6 @@
                                   <object class="GtkImage" id="isol_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -1417,7 +1379,6 @@
                                   <object class="GtkImage" id="ss01_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -1449,7 +1410,6 @@
                                   <object class="GtkImage" id="ss02_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -1481,7 +1441,6 @@
                                   <object class="GtkImage" id="ss03_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -1513,7 +1472,6 @@
                                   <object class="GtkImage" id="ss04_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -1545,7 +1503,6 @@
                                   <object class="GtkImage" id="ss05_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
diff --git a/demos/gtk-demo/gtkfishbowl.c b/demos/gtk-demo/gtkfishbowl.c
index cf19ecb..7d93d97 100644
--- a/demos/gtk-demo/gtkfishbowl.c
+++ b/demos/gtk-demo/gtkfishbowl.c
@@ -411,7 +411,10 @@ gtk_fishbowl_set_count (GtkFishbowl *fishbowl,
       GtkWidget *new_widget;
 
       if (priv->use_icons)
-        new_widget = gtk_image_new_from_icon_name (get_random_icon_name (gtk_icon_theme_get_default ()));
+        {
+          new_widget = gtk_image_new_from_icon_name (get_random_icon_name (gtk_icon_theme_get_default ()));
+          gtk_image_set_icon_size (GTK_IMAGE (new_widget), GTK_ICON_SIZE_LARGE);
+        }
       else
         new_widget = g_object_new (get_random_widget_type (), NULL);
 
diff --git a/demos/gtk-demo/images.c b/demos/gtk-demo/images.c
index 2dfc7c2..b6393cf 100644
--- a/demos/gtk-demo/images.c
+++ b/demos/gtk-demo/images.c
@@ -354,6 +354,7 @@ do_images (GtkWidget *do_widget)
       gtk_box_pack_start (GTK_BOX (vbox), frame);
 
       image = gtk_image_new_from_icon_name ("gtk3-demo");
+      gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_LARGE);
 
       gtk_container_add (GTK_CONTAINER (frame), image);
 
@@ -390,6 +391,7 @@ do_images (GtkWidget *do_widget)
 
       gicon = g_themed_icon_new_with_default_fallbacks ("battery-caution-charging-symbolic");
       image = gtk_image_new_from_gicon (gicon);
+      gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_LARGE);
 
       gtk_container_add (GTK_CONTAINER (frame), image);
 
diff --git a/demos/gtk-demo/listbox.c b/demos/gtk-demo/listbox.c
index 7c96d0c..c1dc9ef 100644
--- a/demos/gtk-demo/listbox.c
+++ b/demos/gtk-demo/listbox.c
@@ -197,7 +197,10 @@ gtk_message_row_update (GtkMessageRow *row)
     gtk_button_set_label (GTK_BUTTON (priv->resent_by_button), priv->message->resent_by);
 
   if (strcmp (priv->message->sender_nick, "@GTKtoolkit") == 0)
-    gtk_image_set_from_icon_name (priv->avatar_image, "gtk3-demo");
+    {
+      gtk_image_set_from_icon_name (priv->avatar_image, "gtk3-demo");
+      gtk_image_set_icon_size (priv->avatar_image, GTK_ICON_SIZE_LARGE);
+    }
   else
     gtk_image_set_from_pixbuf (priv->avatar_image, avatar_pixbuf_other);
 
diff --git a/demos/gtk-demo/revealer.ui b/demos/gtk-demo/revealer.ui
index 7322684..1c0e342 100644
--- a/demos/gtk-demo/revealer.ui
+++ b/demos/gtk-demo/revealer.ui
@@ -19,7 +19,7 @@
               <object class="GtkImage">
                 <property name="visible">1</property>
                 <property name="icon-name">face-cool-symbolic</property>
-                <property name="icon-size">6</property>
+                <property name="icon-size">large</property>
               </object>
             </child>
           </object>
@@ -37,7 +37,7 @@
               <object class="GtkImage">
                 <property name="visible">1</property>
                 <property name="icon-name">face-cool-symbolic</property>
-                <property name="icon-size">6</property>
+                <property name="icon-size">large</property>
               </object>
             </child>
           </object>
@@ -55,7 +55,7 @@
               <object class="GtkImage">
                 <property name="visible">1</property>
                 <property name="icon-name">face-cool-symbolic</property>
-                <property name="icon-size">6</property>
+                <property name="icon-size">large</property>
               </object>
             </child>
           </object>
@@ -72,7 +72,7 @@
               <object class="GtkImage">
                 <property name="visible">1</property>
                 <property name="icon-name">face-cool-symbolic</property>
-                <property name="icon-size">6</property>
+                <property name="icon-size">large</property>
               </object>
             </child>
           </object>
@@ -90,7 +90,7 @@
               <object class="GtkImage">
                 <property name="visible">1</property>
                 <property name="icon-name">face-cool-symbolic</property>
-                <property name="icon-size">6</property>
+                <property name="icon-size">large</property>
               </object>
             </child>
           </object>
@@ -108,7 +108,7 @@
               <object class="GtkImage">
                 <property name="visible">1</property>
                 <property name="icon-name">face-cool-symbolic</property>
-                <property name="icon-size">6</property>
+                <property name="icon-size">large</property>
               </object>
             </child>
           </object>
@@ -126,7 +126,7 @@
               <object class="GtkImage">
                 <property name="visible">1</property>
                 <property name="icon-name">face-cool-symbolic</property>
-                <property name="icon-size">6</property>
+                <property name="icon-size">large</property>
               </object>
             </child>
           </object>
@@ -143,7 +143,7 @@
               <object class="GtkImage">
                 <property name="visible">1</property>
                 <property name="icon-name">face-cool-symbolic</property>
-                <property name="icon-size">6</property>
+                <property name="icon-size">large</property>
               </object>
             </child>
           </object>
@@ -161,7 +161,7 @@
               <object class="GtkImage">
                 <property name="visible">1</property>
                 <property name="icon-name">face-cool-symbolic</property>
-                <property name="icon-size">6</property>
+                <property name="icon-size">large</property>
               </object>
             </child>
           </object>
diff --git a/demos/gtk-demo/toolpalette.c b/demos/gtk-demo/toolpalette.c
index 07712e8..922e499 100644
--- a/demos/gtk-demo/toolpalette.c
+++ b/demos/gtk-demo/toolpalette.c
@@ -43,7 +43,7 @@ canvas_item_new (GtkWidget     *widget,
 
   icon_name = gtk_tool_button_get_icon_name (button);
   icon_theme = gtk_icon_theme_get_for_display (gtk_widget_get_display (widget));
-  gtk_icon_size_lookup (GTK_ICON_SIZE_DIALOG, &width, NULL);
+  gtk_icon_size_lookup (GTK_ICON_SIZE_LARGE, &width, NULL);
   pixbuf = gtk_icon_theme_load_icon (icon_theme,
                                      icon_name,
                                      width,
diff --git a/demos/icon-browser/window.ui b/demos/icon-browser/window.ui
index 4fef775..68c8767 100644
--- a/demos/icon-browser/window.ui
+++ b/demos/icon-browser/window.ui
@@ -50,7 +50,6 @@
               <object class="GtkImage" id="search-icon">
                 <property name="visible">True</property>
                 <property name="icon-name">edit-find-symbolic</property>
-                <property name="icon-size">1</property>
               </object>
             </child>
           </object>
diff --git a/demos/widget-factory/widget-factory.ui b/demos/widget-factory/widget-factory.ui
index 9591386..f533937 100644
--- a/demos/widget-factory/widget-factory.ui
+++ b/demos/widget-factory/widget-factory.ui
@@ -1851,7 +1851,6 @@ microphone-sensitivity-medium-symbolic</property>
                                         <child>
                                           <object class="GtkImage" id="listboxrow3image">
                                             <property name="icon-name">object-select-symbolic</property>
-                                            <property name="icon-size">1</property>
                                             <property name="halign">end</property>
                                             <property name="valign">center</property>
                                             <property name="margin-top">6</property>
@@ -1881,7 +1880,6 @@ microphone-sensitivity-medium-symbolic</property>
                                         <child>
                                           <object class="GtkImage">
                                             <property name="icon-name">object-select-symbolic</property>
-                                            <property name="icon-size">1</property>
                                             <property name="halign">end</property>
                                             <property name="valign">center</property>
                                             <property name="margin-top">6</property>
diff --git a/docs/tools/widgets.c b/docs/tools/widgets.c
index b8fc1f7..8e86962 100644
--- a/docs/tools/widgets.c
+++ b/docs/tools/widgets.c
@@ -144,7 +144,7 @@ create_menu_button (void)
 
   widget = gtk_menu_button_new ();
   image = gtk_image_new ();
-  gtk_image_set_from_icon_name (GTK_IMAGE (image), "emblem-system-symbolic", GTK_ICON_SIZE_MENU);
+  gtk_image_set_from_icon_name (GTK_IMAGE (image), "emblem-system-symbolic");
   gtk_container_add (GTK_CONTAINER (widget), image);
   menu = gtk_menu_new ();
   gtk_menu_button_set_popup (GTK_MENU_BUTTON (widget), menu);
@@ -1074,8 +1074,8 @@ create_image (void)
   GtkWidget *widget;
   GtkWidget *vbox;
 
-  widget = gtk_image_new_from_icon_name ("applications-graphics",
-                                         GTK_ICON_SIZE_DIALOG);
+  widget = gtk_image_new_from_icon_name ("applications-graphics");
+  gtk_image_set_icon_size (GTK_IMAGE (widget), GTK_ICON_SIZE_LARGE);
   gtk_widget_set_halign (widget, GTK_ALIGN_CENTER);
   gtk_widget_set_valign (widget, GTK_ALIGN_CENTER);
 
diff --git a/examples/application10/window.ui b/examples/application10/window.ui
index 270e129..6c02697 100644
--- a/examples/application10/window.ui
+++ b/examples/application10/window.ui
@@ -43,7 +43,6 @@
                   <object class="GtkImage" id="search-icon">
                     <property name="visible">True</property>
                     <property name="icon-name">edit-find-symbolic</property>
-                    <property name="icon-size">1</property>
                   </object>
                 </child>
               </object>
diff --git a/examples/application7/window.ui b/examples/application7/window.ui
index 8f96f89..d500409 100644
--- a/examples/application7/window.ui
+++ b/examples/application7/window.ui
@@ -29,7 +29,6 @@
                   <object class="GtkImage" id="search-icon">
                     <property name="visible">True</property>
                     <property name="icon-name">edit-find-symbolic</property>
-                    <property name="icon-size">1</property>
                   </object>
                 </child>
               </object>
diff --git a/examples/application8/window.ui b/examples/application8/window.ui
index d2a085a..3e51eb7 100644
--- a/examples/application8/window.ui
+++ b/examples/application8/window.ui
@@ -29,7 +29,6 @@
                   <object class="GtkImage" id="search-icon">
                     <property name="visible">True</property>
                     <property name="icon-name">edit-find-symbolic</property>
-                    <property name="icon-size">1</property>
                   </object>
                 </child>
               </object>
diff --git a/examples/application9/window.ui b/examples/application9/window.ui
index f58d10c..c36337b 100644
--- a/examples/application9/window.ui
+++ b/examples/application9/window.ui
@@ -46,7 +46,6 @@
                   <object class="GtkImage" id="search-icon">
                     <property name="visible">True</property>
                     <property name="icon-name">edit-find-symbolic</property>
-                    <property name="icon-size">1</property>
                   </object>
                 </child>
               </object>
diff --git a/gtk/gtkcellrendererpixbuf.c b/gtk/gtkcellrendererpixbuf.c
index 9b258dc..73276b3 100644
--- a/gtk/gtkcellrendererpixbuf.c
+++ b/gtk/gtkcellrendererpixbuf.c
@@ -104,7 +104,7 @@ gtk_cell_renderer_pixbuf_init (GtkCellRendererPixbuf *cellpixbuf)
   priv = cellpixbuf->priv;
 
   priv->image_def = gtk_image_definition_new_empty ();
-  priv->icon_size = GTK_ICON_SIZE_MENU;
+  priv->icon_size = GTK_ICON_SIZE_INHERIT;
 }
 
 static void
@@ -193,7 +193,7 @@ gtk_cell_renderer_pixbuf_class_init (GtkCellRendererPixbufClass *class)
                                                      P_("The GtkIconSize value that specifies the size of 
the rendered icon"),
                                                      0,
                                                      G_MAXUINT,
-                                                     GTK_ICON_SIZE_MENU,
+                                                     GTK_ICON_SIZE_INHERIT,
                                                      GTK_PARAM_READWRITE));
 
   /**
diff --git a/gtk/gtkcellrendererspinner.c b/gtk/gtkcellrendererspinner.c
index 54b1cbd..11b8ff9 100644
--- a/gtk/gtkcellrendererspinner.c
+++ b/gtk/gtkcellrendererspinner.c
@@ -152,7 +152,7 @@ gtk_cell_renderer_spinner_class_init (GtkCellRendererSpinnerClass *klass)
                                    g_param_spec_enum ("size",
                                                       P_("Size"),
                                                       P_("The GtkIconSize value that specifies the size of 
the rendered spinner"),
-                                                      GTK_TYPE_ICON_SIZE, GTK_ICON_SIZE_MENU,
+                                                      GTK_TYPE_ICON_SIZE, GTK_ICON_SIZE_INHERIT,
                                                       G_PARAM_READWRITE|G_PARAM_EXPLICIT_NOTIFY));
 
 }
@@ -162,7 +162,7 @@ gtk_cell_renderer_spinner_init (GtkCellRendererSpinner *cell)
 {
   cell->priv = gtk_cell_renderer_spinner_get_instance_private (cell);
   cell->priv->pulse = 0;
-  cell->priv->icon_size = GTK_ICON_SIZE_MENU;
+  cell->priv->icon_size = GTK_ICON_SIZE_INHERIT;
 }
 
 /**
diff --git a/gtk/gtkenums.h b/gtk/gtkenums.h
index 9460864..a75429b 100644
--- a/gtk/gtkenums.h
+++ b/gtk/gtkenums.h
@@ -175,25 +175,20 @@ typedef enum
 
 /**
  * GtkIconSize:
- * @GTK_ICON_SIZE_INVALID: Invalid size.
- * @GTK_ICON_SIZE_MENU: Size appropriate for menus (16px).
- * @GTK_ICON_SIZE_SMALL_TOOLBAR: Size appropriate for small toolbars (16px).
- * @GTK_ICON_SIZE_LARGE_TOOLBAR: Size appropriate for large toolbars (24px)
- * @GTK_ICON_SIZE_BUTTON: Size appropriate for buttons (16px)
- * @GTK_ICON_SIZE_DND: Size appropriate for drag and drop (32px)
- * @GTK_ICON_SIZE_DIALOG: Size appropriate for dialogs (48px)
+ * @GTK_ICON_SIZE_INHERIT: Keep the size of the parent element
+ * @GTK_ICON_SIZE_NORMAL: Size similar to text size
+ * @GTK_ICON_SIZE_LARGE: Large size, for example in an icon view
  *
- * Built-in stock icon sizes.
+ * Built-in icon sizes.
+ *
+ * Icon sizes default to being inherited. Where they cannot be
+ * inherited, text size is the default.
  */
 typedef enum
 {
-  GTK_ICON_SIZE_INVALID,
-  GTK_ICON_SIZE_MENU,
-  GTK_ICON_SIZE_SMALL_TOOLBAR,
-  GTK_ICON_SIZE_LARGE_TOOLBAR,
-  GTK_ICON_SIZE_BUTTON,
-  GTK_ICON_SIZE_DND,
-  GTK_ICON_SIZE_DIALOG
+  GTK_ICON_SIZE_INHERIT,
+  GTK_ICON_SIZE_NORMAL,
+  GTK_ICON_SIZE_LARGE
 } GtkIconSize;
 
 /**
diff --git a/gtk/gtkiconhelper.c b/gtk/gtkiconhelper.c
index 31b2835..543551e 100644
--- a/gtk/gtkiconhelper.c
+++ b/gtk/gtkiconhelper.c
@@ -113,6 +113,7 @@ gtk_icon_helper_init (GtkIconHelper *self,
   memset (self, 0, sizeof (GtkIconHelper));
   self->def = gtk_image_definition_new_empty ();
 
+  self->icon_size = GTK_ICON_SIZE_INHERIT;
   self->pixel_size = -1;
   self->texture_is_symbolic = FALSE;
 
@@ -135,7 +136,7 @@ ensure_icon_size (GtkIconHelper *self,
     }
   else if (!gtk_icon_size_lookup (self->icon_size, &width, &height))
     {
-      if (self->icon_size == GTK_ICON_SIZE_INVALID)
+      if (self->icon_size == GTK_ICON_SIZE_INHERIT)
         {
           width = height = 0;
         }
@@ -455,7 +456,7 @@ _gtk_icon_helper_get_size (GtkIconHelper *self,
           width = (gdk_texture_get_width (self->texture) + self->texture_scale - 1) / self->texture_scale;
           height = (gdk_texture_get_height (self->texture) + self->texture_scale - 1) / self->texture_scale;
         }
-      else if (self->icon_size != GTK_ICON_SIZE_INVALID)
+      else if (self->icon_size != GTK_ICON_SIZE_INHERIT)
         {
           ensure_icon_size (self, &width, &height);
         }
diff --git a/gtk/gtkimage.c b/gtk/gtkimage.c
index bdaac34..a24ef9a 100644
--- a/gtk/gtkimage.c
+++ b/gtk/gtkimage.c
@@ -83,7 +83,7 @@ struct _GtkImagePrivate
 };
 
 
-#define DEFAULT_ICON_SIZE GTK_ICON_SIZE_BUTTON
+#define DEFAULT_ICON_SIZE GTK_ICON_SIZE_INHERIT
 static void gtk_image_snapshot             (GtkWidget    *widget,
                                             GtkSnapshot  *snapshot);
 static void gtk_image_size_allocate        (GtkWidget           *widget,
@@ -1395,7 +1395,7 @@ gtk_image_get_icon_size (GtkImage *image)
 {
   GtkImagePrivate *priv = gtk_image_get_instance_private (image);
 
-  g_return_val_if_fail (GTK_IS_IMAGE (image), GTK_ICON_SIZE_INVALID);
+  g_return_val_if_fail (GTK_IS_IMAGE (image), GTK_ICON_SIZE_INHERIT);
 
   return _gtk_icon_helper_get_icon_size (&priv->icon_helper);
 }
diff --git a/gtk/gtkmountoperation.c b/gtk/gtkmountoperation.c
index 58a3a0e..ebf3635 100644
--- a/gtk/gtkmountoperation.c
+++ b/gtk/gtkmountoperation.c
@@ -550,6 +550,7 @@ gtk_mount_operation_ask_password_do_gtk (GtkMountOperation *operation,
   gtk_box_pack_start (GTK_BOX (content_area), hbox);
 
   icon = gtk_image_new_from_icon_name ("dialog-password");
+  gtk_image_set_icon_size (GTK_IMAGE (icon), GTK_ICON_SIZE_LARGE);
 
   gtk_widget_set_halign (icon, GTK_ALIGN_CENTER);
   gtk_widget_set_valign (icon, GTK_ALIGN_START);
diff --git a/gtk/gtkprintbackend.c b/gtk/gtkprintbackend.c
index e8f821a..38bb769 100644
--- a/gtk/gtkprintbackend.c
+++ b/gtk/gtkprintbackend.c
@@ -770,6 +770,7 @@ request_password (GtkPrintBackend  *backend,
 
   /* Left */
   icon = gtk_image_new_from_icon_name ("dialog-password-symbolic");
+  gtk_image_set_icon_size (GTK_IMAGE (icon), GTK_ICON_SIZE_LARGE);
   gtk_widget_set_halign (icon, GTK_ALIGN_CENTER);
   gtk_widget_set_valign (icon, GTK_ALIGN_START);
   g_object_set (icon, "margin", 12, NULL);
diff --git a/gtk/gtkprintunixdialog.c b/gtk/gtkprintunixdialog.c
index 4480005..5b31d59 100644
--- a/gtk/gtkprintunixdialog.c
+++ b/gtk/gtkprintunixdialog.c
@@ -2312,7 +2312,7 @@ gtk_print_unix_dialog_style_updated (GtkWidget *widget)
 
   GTK_WIDGET_CLASS (gtk_print_unix_dialog_parent_class)->style_updated (widget);
 
-  gtk_icon_size_lookup (GTK_ICON_SIZE_DIALOG, &size, NULL);
+  gtk_icon_size_lookup (GTK_ICON_SIZE_LARGE, &size, NULL);
   scale = size / 48.0;
 
   gtk_drawing_area_set_content_width (GTK_DRAWING_AREA (priv->collate_image), (50 + 20) * scale);
diff --git a/gtk/gtkrecentchooserdefault.c b/gtk/gtkrecentchooserdefault.c
index 4eca2d4..f8e3e58 100644
--- a/gtk/gtkrecentchooserdefault.c
+++ b/gtk/gtkrecentchooserdefault.c
@@ -77,8 +77,6 @@ typedef struct
   gulong manager_changed_id;
   guint local_manager : 1;
 
-  gint icon_size;
-
   /* RecentChooser properties */
   gint limit;
   GtkRecentSortType sort_type;
@@ -352,7 +350,6 @@ _gtk_recent_chooser_default_init (GtkRecentChooserDefault *impl)
   priv->select_multiple = FALSE;
   priv->local_only = TRUE;
   
-  priv->icon_size = FALLBACK_ICON_SIZE;
   priv->icon_theme = NULL;
   
   priv->current_filter = NULL;
@@ -776,9 +773,6 @@ reload_recent_items (GtkRecentChooserDefault *impl)
   if (!impl->priv->icon_theme)
     impl->priv->icon_theme = get_icon_theme_for_widget (widget);
 
-  impl->priv->icon_size = get_icon_size_for_widget (widget,
-                                             GTK_ICON_SIZE_BUTTON);
-
   if (!impl->priv->limit_set)
     impl->priv->limit = DEFAULT_RECENT_FILES_LIMIT;
 
@@ -812,8 +806,8 @@ set_default_size (GtkRecentChooserDefault *impl)
   /* Size based on characters and the icon size */
   gtk_style_context_get (context, "font-size", &font_size, NULL);
 
-  width = impl->priv->icon_size + font_size * NUM_CHARS + 0.5;
-  height = (impl->priv->icon_size + font_size) * NUM_LINES + 0.5;
+  width = 16 + font_size * NUM_CHARS + 0.5;
+  height = (16 + font_size) * NUM_LINES + 0.5;
 
   /* Use at least the requisition size... */
   gtk_widget_get_preferred_size (widget, &req, NULL);
@@ -1336,7 +1330,7 @@ get_drag_surface (GtkRecentChooserDefault *impl)
 
   g_assert (GTK_IS_RECENT_CHOOSER_DEFAULT (impl));
 
-  size = get_icon_size_for_widget (GTK_WIDGET (impl), GTK_ICON_SIZE_DND);
+  size = get_icon_size_for_widget (GTK_WIDGET (impl), GTK_ICON_SIZE_NORMAL);
   info = gtk_recent_chooser_get_current_item (GTK_RECENT_CHOOSER (impl));
   if (!info)
     return NULL;
diff --git a/gtk/gtkstackswitcher.c b/gtk/gtkstackswitcher.c
index b806230..d545a6f 100644
--- a/gtk/gtkstackswitcher.c
+++ b/gtk/gtkstackswitcher.c
@@ -89,7 +89,7 @@ gtk_stack_switcher_init (GtkStackSwitcher *switcher)
 
   priv = gtk_stack_switcher_get_instance_private (switcher);
 
-  priv->icon_size = GTK_ICON_SIZE_MENU;
+  priv->icon_size = GTK_ICON_SIZE_INHERIT;
   priv->stack = NULL;
   priv->buttons = g_hash_table_new (g_direct_hash, g_direct_equal);
 
@@ -681,7 +681,7 @@ gtk_stack_switcher_class_init (GtkStackSwitcherClass *class)
                                                      P_("Icon Size"),
                                                      P_("Symbolic size to use for named icon"),
                                                      0, G_MAXINT,
-                                                     GTK_ICON_SIZE_MENU,
+                                                     GTK_ICON_SIZE_INHERIT,
                                                      G_PARAM_EXPLICIT_NOTIFY | GTK_PARAM_READWRITE));
 
   g_object_class_install_property (object_class,
diff --git a/gtk/gtktoolbutton.c b/gtk/gtktoolbutton.c
index a100674..ce6f63b 100644
--- a/gtk/gtktoolbutton.c
+++ b/gtk/gtktoolbutton.c
@@ -450,13 +450,6 @@ gtk_tool_button_construct_contents (GtkToolItem *tool_item)
       if (button->priv->icon_widget)
        {
          icon = button->priv->icon_widget;
-
-         if (GTK_IS_IMAGE (icon))
-           {
-             g_object_set (button->priv->icon_widget,
-                           "icon-size", GTK_ICON_SIZE_SMALL_TOOLBAR,
-                           NULL);
-           }
        }
       else if (button->priv->icon_name)
        {
@@ -725,7 +718,7 @@ clone_image_menu_size (GtkImage *image)
     {
       gint width, height;
 
-      if (gtk_icon_size_lookup (GTK_ICON_SIZE_MENU, &width, &height))
+      if (gtk_icon_size_lookup (GTK_ICON_SIZE_NORMAL, &width, &height))
         {
           cairo_surface_t *src_surface, *dest_surface;
           GtkWidget *cloned_image;
diff --git a/gtk/inspector/general.ui b/gtk/inspector/general.ui
index e826c54..0188cb0 100644
--- a/gtk/inspector/general.ui
+++ b/gtk/inspector/general.ui
@@ -429,7 +429,6 @@
                             <property name="halign">end</property>
                             <property name="valign">baseline</property>
                             <property name="icon-name">object-select-symbolic</property>
-                            <property name="icon-size">1</property>
                             <property name="hexpand">1</property>
                           </object>
                         </child>
@@ -461,7 +460,6 @@
                             <property name="halign">end</property>
                             <property name="valign">baseline</property>
                             <property name="icon-name">object-select-symbolic</property>
-                            <property name="icon-size">1</property>
                             <property name="hexpand">1</property>
                           </object>
                         </child>
diff --git a/gtk/inspector/misc-info.ui b/gtk/inspector/misc-info.ui
index bdc3705..4d6526c 100644
--- a/gtk/inspector/misc-info.ui
+++ b/gtk/inspector/misc-info.ui
@@ -462,7 +462,6 @@
                             <property name="halign">end</property>
                             <property name="valign">baseline</property>
                             <property name="icon-name">object-select-symbolic</property>
-                            <property name="icon-size">1</property>
                           </object>
                         </child>
                       </object>
@@ -659,7 +658,6 @@
                             <property name="visible">true</property>
                             <property name="halign">end</property>
                             <property name="valign">baseline</property>
-                            <property name="icon-size">1</property>
                             <property name="icon-name">object-select-symbolic</property>
                           </object>
                         </child>
@@ -693,7 +691,6 @@
                             <property name="visible">true</property>
                             <property name="halign">end</property>
                             <property name="valign">baseline</property>
-                            <property name="icon-size">1</property>
                             <property name="icon-name">object-select-symbolic</property>
                           </object>
                         </child>
@@ -727,7 +724,6 @@
                             <property name="visible">true</property>
                             <property name="halign">end</property>
                             <property name="valign">baseline</property>
-                            <property name="icon-size">1</property>
                             <property name="icon-name">object-select-symbolic</property>
                           </object>
                         </child>
@@ -761,7 +757,6 @@
                             <property name="visible">true</property>
                             <property name="halign">end</property>
                             <property name="valign">baseline</property>
-                            <property name="icon-size">1</property>
                             <property name="icon-name">object-select-symbolic</property>
                           </object>
                         </child>
diff --git a/gtk/ui/gtkpagesetupunixdialog.ui b/gtk/ui/gtkpagesetupunixdialog.ui
index 3eb6edd..4d2dabe 100644
--- a/gtk/ui/gtkpagesetupunixdialog.ui
+++ b/gtk/ui/gtkpagesetupunixdialog.ui
@@ -144,7 +144,6 @@
                       <object class="GtkImage" id="image1">
                         <property name="visible">1</property>
                         <property name="icon-name">gtk-orientation-portrait</property>
-                        <property name="icon-size">3</property>
                       </object>
                     </child>
                     <child>
@@ -180,7 +179,6 @@
                       <object class="GtkImage" id="image2">
                         <property name="visible">1</property>
                         <property name="icon-name">gtk-orientation-reverse-portrait</property>
-                        <property name="icon-size">3</property>
                       </object>
                     </child>
                     <child>
@@ -216,7 +214,6 @@
                       <object class="GtkImage" id="image3">
                         <property name="visible">1</property>
                         <property name="icon-name">gtk-orientation-landscape</property>
-                        <property name="icon-size">3</property>
                       </object>
                     </child>
                     <child>
@@ -251,7 +248,6 @@
                       <object class="GtkImage" id="image4">
                         <property name="visible">1</property>
                         <property name="icon-name">gtk-orientation-reverse-landscape</property>
-                        <property name="icon-size">3</property>
                       </object>
                     </child>
                     <child>
diff --git a/gtk/ui/gtkpathbar.ui b/gtk/ui/gtkpathbar.ui
index 9305ddb..2a76c95 100644
--- a/gtk/ui/gtkpathbar.ui
+++ b/gtk/ui/gtkpathbar.ui
@@ -17,7 +17,6 @@
     <child>
       <object class="GtkImage">
         <property name="icon-name">pan-end-symbolic</property>
-        <property name="icon-size">1</property>
       </object>
     </child>
     <style>
@@ -40,7 +39,6 @@
     <child>
       <object class="GtkImage">
         <property name="icon-name">pan-start-symbolic</property>
-        <property name="icon-size">1</property>
       </object>
     </child>
     <style>
diff --git a/gtk/ui/gtkplacesviewrow.ui b/gtk/ui/gtkplacesviewrow.ui
index d7628e6..975945c 100644
--- a/gtk/ui/gtkplacesviewrow.ui
+++ b/gtk/ui/gtkplacesviewrow.ui
@@ -71,7 +71,6 @@
                   <object class="GtkImage" id="eject_icon">
                     <property name="visible">1</property>
                     <property name="icon-name">media-eject-symbolic</property>
-                    <property name="icon-size">1</property>
                   </object>
                 </child>
                 <style>
diff --git a/gtk/ui/gtkprintunixdialog.ui b/gtk/ui/gtkprintunixdialog.ui
index c61a380..abce362 100644
--- a/gtk/ui/gtkprintunixdialog.ui
+++ b/gtk/ui/gtkprintunixdialog.ui
@@ -1269,7 +1269,6 @@
                   <object class="GtkImage" id="image1">
                     <property name="visible">1</property>
                     <property name="icon-name">dialog-warning-symbolic</property>
-                    <property name="icon-size">1</property>
                   </object>
                 </child>
                 <child>
diff --git a/gtk/ui/gtksearchbar.ui b/gtk/ui/gtksearchbar.ui
index 7370142..025c72f 100644
--- a/gtk/ui/gtksearchbar.ui
+++ b/gtk/ui/gtksearchbar.ui
@@ -41,7 +41,6 @@
                     </style>
                     <child>
                       <object class="GtkImage" id="close_image">
-                        <property name="icon-size">1</property>
                         <property name="icon-name">window-close-symbolic</property>
                       </object>
                     </child>
diff --git a/tests/dialog.ui b/tests/dialog.ui
index 58d3f34..8c7a97f 100644
--- a/tests/dialog.ui
+++ b/tests/dialog.ui
@@ -34,7 +34,6 @@
             <child>
               <object class="GtkImage" id="back_icon">
                 <property name="visible">True</property>
-                <property name="icon_size">1</property>
               </object>
             </child>
           </object>
diff --git a/tests/selectionmode.ui b/tests/selectionmode.ui
index abe79d1..7e6c593 100644
--- a/tests/selectionmode.ui
+++ b/tests/selectionmode.ui
@@ -27,7 +27,6 @@
               <object class="GtkImage">
                 <property name="visible">True</property>
                 <property name="icon-name">emblem-system-symbolic</property>
-                <property name="icon-size">1</property>
               </object>
             </child>
           </object>
@@ -67,7 +66,6 @@
                       <object class="GtkImage">
                         <property name="visible">True</property>
                         <property name="icon-name">pan-down-symbolic</property>
-                        <property name="icon-size">1</property>
                       </object>
                     </child>
                   </object>
@@ -89,7 +87,6 @@
               <object class="GtkImage">
                 <property name="visible">True</property>
                 <property name="icon-name">object-select-symbolic</property>
-                <property name="icon-size">1</property>
               </object>
             </child>
           </object>
diff --git a/tests/testdnd2.c b/tests/testdnd2.c
index f9afae1..287a41c 100644
--- a/tests/testdnd2.c
+++ b/tests/testdnd2.c
@@ -8,7 +8,6 @@ get_image_surface (GtkImage *image,
   const char *icon_name;
   int width;
   cairo_surface_t *surface;
-  GtkIconSize size;
 
   switch (gtk_image_get_storage_type (image))
     {
@@ -18,9 +17,8 @@ get_image_surface (GtkImage *image,
       return cairo_surface_reference (surface);
     case GTK_IMAGE_ICON_NAME:
       icon_name = gtk_image_get_icon_name (image);
-      size = gtk_image_get_icon_size (image);
       icon_theme = gtk_icon_theme_get_for_display (gtk_widget_get_display (GTK_WIDGET (image)));
-      gtk_icon_size_lookup (size, &width, NULL);
+      gtk_icon_size_lookup (GTK_ICON_SIZE_LARGE, &width, NULL);
       *out_size = width;
       return gtk_icon_theme_load_surface (icon_theme, icon_name, width, 1, NULL, 
GTK_ICON_LOOKUP_GENERIC_FALLBACK, NULL);
     default:
@@ -226,6 +224,7 @@ make_image (const gchar *icon_name, int hotspot)
   GtkWidget *image;
 
   image = gtk_image_new_from_icon_name (icon_name);
+  gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_LARGE);
 
   gtk_drag_source_set (image, GDK_BUTTON1_MASK, NULL, 0, GDK_ACTION_COPY);
   update_source_target_list (image);
@@ -248,6 +247,7 @@ make_image2 (const gchar *icon_name, int hotspot)
   GtkWidget *image;
 
   image = gtk_image_new_from_icon_name (icon_name);
+  gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_LARGE);
 
   gtk_drag_source_set (image, GDK_BUTTON1_MASK, NULL, 0, GDK_ACTION_COPY);
   update_source_target_list (image);
diff --git a/tests/testflowbox.c b/tests/testflowbox.c
index 7721965..2209278 100644
--- a/tests/testflowbox.c
+++ b/tests/testflowbox.c
@@ -170,6 +170,7 @@ populate_flowbox_images (GtkFlowBox *flowbox)
       gtk_widget_set_hexpand (widget, TRUE);
 
       image = gtk_image_new_from_icon_name ("face-wink");
+      gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_LARGE);
       gtk_widget_set_hexpand (image, TRUE);
       gtk_image_set_pixel_size (GTK_IMAGE (image), 256);
 
diff --git a/tests/testgiconpixbuf.c b/tests/testgiconpixbuf.c
index 6900f5e..2ce7f6c 100644
--- a/tests/testgiconpixbuf.c
+++ b/tests/testgiconpixbuf.c
@@ -44,6 +44,7 @@ main (int argc,
   gtk_box_pack_start (GTK_BOX (hbox), vbox);
 
   image = gtk_image_new_from_gicon (G_ICON (pixbuf));
+  gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_LARGE);
   gtk_box_pack_start (GTK_BOX (vbox), image);
 
   label = gtk_label_new (NULL);
@@ -59,6 +60,7 @@ main (int argc,
   gtk_box_pack_start (GTK_BOX (hbox), vbox);
 
   image2 = gtk_image_new_from_gicon (emblemed);
+  gtk_image_set_icon_size (GTK_IMAGE (image2), GTK_ICON_SIZE_LARGE);
   gtk_box_pack_start (GTK_BOX (vbox), image2);
 
   label = gtk_label_new (NULL);
diff --git a/tests/testimage.c b/tests/testimage.c
index 106a33e..0c6374c 100644
--- a/tests/testimage.c
+++ b/tests/testimage.c
@@ -133,8 +133,10 @@ main (int argc, char **argv)
   label = gtk_label_new ("GTK_IMAGE_ICON_NAME");
   gtk_grid_attach (GTK_GRID (grid), label, 0, 4, 1, 1);
   image = gtk_image_new_from_icon_name (icon_name);
+  gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_LARGE);
   gtk_grid_attach (GTK_GRID (grid), image, 1, 4, 1, 1);
   image = gtk_image_new_from_icon_name (icon_name);
+  gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_LARGE);
   gtk_image_set_pixel_size (GTK_IMAGE (image), 30);
   gtk_grid_attach (GTK_GRID (grid), image, 2, 4, 1, 1);
 
@@ -142,11 +144,13 @@ main (int argc, char **argv)
   gtk_grid_attach (GTK_GRID (grid), label, 0, 5, 1, 1);
   icon = g_themed_icon_new_with_default_fallbacks ("folder-remote");
   image = gtk_image_new_from_gicon (icon);
+  gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_LARGE);
   g_object_unref (icon);
   gtk_grid_attach (GTK_GRID (grid), image, 1, 5, 1, 1);
   file = g_file_new_for_path ("apple-red.png");
   icon = g_file_icon_new (file);
   image = gtk_image_new_from_gicon (icon);
+  gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_LARGE);
   g_object_unref (icon);
   gtk_image_set_pixel_size (GTK_IMAGE (image), 30);
   gtk_grid_attach (GTK_GRID (grid), image, 2, 5, 1, 1);
diff --git a/tests/testnotebookdnd.c b/tests/testnotebookdnd.c
index cf398a8..2952755 100644
--- a/tests/testnotebookdnd.c
+++ b/tests/testnotebookdnd.c
@@ -96,28 +96,14 @@ on_notebook_drag_begin (GtkWidget      *widget,
                         GdkDragContext *context,
                         gpointer        data)
 {
-  cairo_surface_t *surface;
   guint page_num;
 
   page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (widget));
 
   if (page_num > 2)
-    {
-      GtkIconTheme *icon_theme;
-      int width;
-
-      icon_theme = gtk_icon_theme_get_for_display (gtk_widget_get_display (widget));
-      gtk_icon_size_lookup (GTK_ICON_SIZE_DND, &width, NULL);
-      surface = gtk_icon_theme_load_surface (icon_theme,
-                                             (page_num % 2) ? "help-browser" : "process-stop",
-                                             width,
-                                             1, NULL,
-                                             GTK_ICON_LOOKUP_GENERIC_FALLBACK,
-                                             NULL);
-
-      gtk_drag_set_icon_surface (context, surface);
-      cairo_surface_destroy (surface);
-    }
+    gtk_drag_set_icon_name (context,
+                            (page_num % 2) ? "help-browser" : "process-stop",
+                            0, 0);
 }
 
 static gboolean
diff --git a/tests/testtoolbar.c b/tests/testtoolbar.c
index 97f2e0e..7ee0480 100644
--- a/tests/testtoolbar.c
+++ b/tests/testtoolbar.c
@@ -557,6 +557,7 @@ main (gint argc, gchar **argv)
   gtk_toolbar_insert (GTK_TOOLBAR (toolbar), item, -1);
   
   image = gtk_image_new_from_icon_name ("dialog-warning");
+  gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_LARGE);
   item = gtk_tool_item_new ();
   gtk_widget_show (image);
   gtk_container_add (GTK_CONTAINER (item), image);
diff --git a/tests/testverticalcells.c b/tests/testverticalcells.c
index 8a3cbdc..15512e1 100644
--- a/tests/testverticalcells.c
+++ b/tests/testverticalcells.c
@@ -322,7 +322,7 @@ main (gint argc, gchar **argv)
   column = gtk_tree_view_column_new ();
 
   renderer = gtk_cell_renderer_pixbuf_new ();
-  g_object_set (renderer, "stock-size", GTK_ICON_SIZE_DIALOG, NULL);
+  g_object_set (renderer, "stock-size", GTK_ICON_SIZE_LARGE, NULL);
   gtk_tree_view_column_pack_start (column, renderer, TRUE);
   gtk_tree_view_column_set_attributes (column, renderer,
                                       "icon-name", ICON_COLUMN, NULL);
diff --git a/tests/visuals/osd-toolbars.ui b/tests/visuals/osd-toolbars.ui
index 3ac7df6..ac8ae62 100644
--- a/tests/visuals/osd-toolbars.ui
+++ b/tests/visuals/osd-toolbars.ui
@@ -39,7 +39,6 @@
                           <object class="GtkImage" id="camera_icon">
                             <property name="visible">True</property>
                             <property name="icon_name">camera-web-symbolic</property>
-                            <property name="icon_size">1</property>
                           </object>
                         </child>
                       </object>
@@ -52,7 +51,6 @@
                           <object class="GtkImage" id="volume_icon">
                             <property name="visible">True</property>
                             <property name="icon_name">audio-volume-medium-symbolic</property>
-                            <property name="icon_size">1</property>
                           </object>
                         </child>
                       </object>
@@ -65,7 +63,6 @@
                           <object class="GtkImage" id="microphone_icon">
                             <property name="visible">True</property>
                             <property name="icon_name">audio-input-microphone-symbolic</property>
-                            <property name="icon_size">1</property>
                           </object>
                         </child>
                       </object>
@@ -79,7 +76,6 @@
                           <object class="GtkImage" id="bt_icon">
                             <property name="visible">True</property>
                             <property name="icon_name">bluetooth-active-symbolic</property>
-                            <property name="icon_size">1</property>
                           </object>
                         </child>
                       </object>
@@ -125,7 +121,6 @@
                           <object class="GtkImage" id="opt_icon">
                             <property name="visible">True</property>
                             <property name="icon_name">media-optical-symbolic</property>
-                            <property name="icon_size">1</property>
                           </object>
                         </child>
                       </object>
@@ -138,7 +133,6 @@
                           <object class="GtkImage" id="hdd_icon">
                             <property name="visible">True</property>
                             <property name="icon_name">drive-harddisk-symbolic</property>
-                            <property name="icon_size">1</property>
                           </object>
                         </child>
                       </object>
@@ -151,7 +145,6 @@
                           <object class="GtkImage" id="joy_icon">
                             <property name="visible">True</property>
                             <property name="icon_name">input-gaming-symbolic</property>
-                            <property name="icon_size">1</property>
                           </object>
                         </child>
                       </object>
@@ -169,7 +162,6 @@
             <property name="halign">center</property>
             <property name="valign">start</property>
             <property name="margin_top">24</property>
-            <property name="icon_size">1</property>
             <style>
                 <class name="osd"/>
             </style>
diff --git a/testsuite/reftests/gtk-icontheme-sizing.ref.ui b/testsuite/reftests/gtk-icontheme-sizing.ref.ui
index 7e7861d..5f99d6b 100644
--- a/testsuite/reftests/gtk-icontheme-sizing.ref.ui
+++ b/testsuite/reftests/gtk-icontheme-sizing.ref.ui
@@ -11,7 +11,6 @@
         <property name="can_focus">False</property>
         <property name="pixel_size">100</property>
         <property name="icon_name">pan-down-symbolic</property>
-        <property name="icon_size">0</property>
       </object>
     </child>
   </object>
diff --git a/testsuite/reftests/icon-vfuncs.ui b/testsuite/reftests/icon-vfuncs.ui
index 7c0db70..f2f215a 100644
--- a/testsuite/reftests/icon-vfuncs.ui
+++ b/testsuite/reftests/icon-vfuncs.ui
@@ -109,7 +109,6 @@
             <property name="visible">True</property>
             <property name="can_focus">False</property>
             <property name="icon_name">pan-down-symbolic</property>
-            <property name="icon_size">1</property>
             <property name="halign">center</property>
             <property name="valign">center</property>
           </object>
diff --git a/testsuite/reftests/iconview-empty.ref.ui b/testsuite/reftests/iconview-empty.ref.ui
index b312b6b..78e8798 100644
--- a/testsuite/reftests/iconview-empty.ref.ui
+++ b/testsuite/reftests/iconview-empty.ref.ui
@@ -16,7 +16,6 @@
             <property name="can_focus">False</property>
             <property name="halign">center</property>
             <property name="valign">center</property>
-            <property name="icon-size">0</property>
             <property name="width-request">0</property>
             <property name="height-request">0</property>
           </object>
@@ -33,7 +32,6 @@
             <property name="can_focus">False</property>
             <property name="halign">center</property>
             <property name="valign">center</property>
-            <property name="icon-size">0</property>
             <property name="width-request">0</property>
             <property name="height-request">0</property>
           </object>
@@ -50,7 +48,6 @@
             <property name="can_focus">False</property>
             <property name="halign">center</property>
             <property name="valign">center</property>
-            <property name="icon-size">0</property>
             <property name="width-request">0</property>
             <property name="height-request">0</property>
           </object>


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/gtk/gtkicontheme.c b/gtk/gtkicontheme.c
index 1dc44a5..239ea4e 100644
--- a/gtk/gtkicontheme.c
+++ b/gtk/gtkicontheme.c
@@ -5352,48 +5352,23 @@ typedef struct _IconSize IconSize;
 
 struct _IconSize
 {
-  const char *name;
-
   int width;
   int height;
 };
 
 static const IconSize icon_sizes[] = {
-  [GTK_ICON_SIZE_INVALID] = {
-    .name = NULL,
-    .width = 0,
-    .height = 0,
-  },
-  [GTK_ICON_SIZE_MENU] = {
-    .name = "gtk-menu",
-    .width = 16,
-    .height = 16,
-  },
-  [GTK_ICON_SIZE_BUTTON] = {
-    .name = "gtk-button",
+  [GTK_ICON_SIZE_INHERIT] = {
     .width = 16,
     .height = 16,
   },
-  [GTK_ICON_SIZE_SMALL_TOOLBAR] = {
-    .name = "gtk-small-toolbar",
+  [GTK_ICON_SIZE_NORMAL] = {
     .width = 16,
     .height = 16,
   },
-  [GTK_ICON_SIZE_LARGE_TOOLBAR] = {
-    .name = "gtk-large-toolbar",
-    .width = 24,
-    .height = 24,
-  },
-  [GTK_ICON_SIZE_DND] = {
-    .name = "gtk-dnd",
+  [GTK_ICON_SIZE_LARGE] = {
     .width = 32,
     .height = 32,
   },
-  [GTK_ICON_SIZE_DIALOG] = {
-    .name = "gtk-dialog",
-    .width = 48,
-    .height = 48,
-  },
 };
 
 /**
@@ -5403,7 +5378,7 @@ static const IconSize icon_sizes[] = {
  * @height: (out) (optional): location to store icon height
  *
  * Obtains the pixel size of a semantic icon size @size:
  * #GTK_ICON_SIZE_MENU, #GTK_ICON_SIZE_BUTTON, etc.  This function
  * isn’t normally needed, gtk_icon_theme_load_icon() is the usual
  * way to get an icon for rendering, then just look at the size of
  * the rendered pixbuf. The rendered pixbuf may not even correspond to
@@ -5427,9 +5402,6 @@ gtk_icon_size_lookup (GtkIconSize  size,
   if (size >= G_N_ELEMENTS (icon_sizes))
     return FALSE;
 
-  if (size == GTK_ICON_SIZE_INVALID)
-    return FALSE;
-
   if (widthp)
     *widthp = icon_sizes[size].width;
 
@@ -5403,7 +5378,7 @@ static const IconSize icon_sizes[] = {
  *
  * Obtains the pixel size of a semantic icon size @size:
- * #GTK_ICON_SIZE_MENU, #GTK_ICON_SIZE_BUTTON, etc.  This function
+ * #GTK_ICON_NORMAL, #GTK_ICON_SIZE_LARGE, etc.  This function
  * isn’t normally needed, gtk_icon_theme_load_icon() is the usual
  * way to get an icon for rendering, then just look at the size of